@@ -11,8 +11,8 @@ package Spreadsheet::Edit::Log;
 
 # Allow "use <thismodule. VERSION ..." in development sandbox to not bomb
 { no strict 'refs'; ${__PACKAGE__."::VER"."SION"} = 1999.999; }
-our $VERSION = '1000.011'; # VERSION from Dist::Zilla::Plugin::OurPkgVersion
-our $DATE = '2023-10-28'; # DATE from Dist::Zilla::Plugin::OurDate
+our $VERSION = '1000.012'; # VERSION from Dist::Zilla::Plugin::OurPkgVersion
+our $DATE = '2024-01-08'; # DATE from Dist::Zilla::Plugin::OurDate
 
 use Carp;
 
@@ -23,10 +23,9 @@ our @EXPORT = qw/fmt_call log_call fmt_methcall log_methcall
 my $default_pfx = '$lno';
 
 sub _btwTN($$@) {
-  local ($@, $_); # dont clobber callers variables
+  local ($@, $_); # dont clobber caller's variables
   my ($pfxexpr, $N, @strings) = @_;
   local $_ = join("", @strings);
-#Carp::cluck "-----pfxexpr=$pfxexpr N=$N strings=@strings\n";
   $pfxexpr = $default_pfx if $pfxexpr eq "__DEFAULT__";
   s/\n\z//s;
   my @levels;
@@ -61,6 +60,9 @@ sub _btwTN($$@) {
     $pfx .= $sep if $pfx;
     $pfx .= $s;
   }
+  if (ref($N) eq "") {
+    foreach (2..$N) { $pfx .= "«" }
+  }
   print STDERR "${pfx}: $_\n";
 }
 
@@ -116,12 +118,17 @@ use List::Util qw/first any all/;
 use File::Basename qw/dirname basename/;
 
 sub oops(@) {
+  my $pkg = caller;
+  my $pfx = "\nOOPS";
+  $pfx .= " in pkg '$pkg'" unless $pkg eq 'main';
+  $pfx .= ":\n";
   if (defined(&Spreadsheet::Edit::logmsg)) {
     # Show current apply sheet & row if any.
-    @_=("\n".(caller)." oops:\n",&Spreadsheet::Edit::logmsg(@_),"\n");
+    @_=($pfx, &Spreadsheet::Edit::logmsg(@_));
   } else {
-    @_=("\n".(caller)." oops:\n",@_,"\n");
+    @_=($pfx, @_);
   }
+  push @_,"\n" unless $_[-1] =~ /\R\z/;
   goto &Carp::confess
 }
 
